#
# spec file for package python-Ming
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Ming
Version:        0.9.2
Release:        lp152.1.1
Summary:        Bringing order to Mongo since 2009
License:        MIT
Group:          Development/Languages/Python
URL:            http://merciless.sourceforge.net
Source:         https://files.pythonhosted.org/packages/source/M/Ming/Ming-%{version}.tar.gz
Patch0:         0001-disable_test_gridfs.patch
Patch1:         pymongo-reqs.patch
BuildRequires:  %{python_module FormEncode >= 1.2.1}
BuildRequires:  %{python_module WebOb}
BuildRequires:  %{python_module WebTest}
BuildRequires:  %{python_module mock >= 0.8.0}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pymongo >= 2.4}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pymongo >= 3.0
Requires:       python-pytz
Requires:       python-six >= 1.6.1
Recommends:     python-FormEncode >= 1.2.1
Recommends:     python-python-spidermonkey >= 0.0.10
BuildArch:      noarch
%python_subpackages

%description
Database mapping layer for MongoDB on Python. Includes schema enforcement and some facilities for schema migration.

%prep
%setup -q -n Ming-%{version}
%patch0 -p1
%patch1 -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec setup.py -q test

%files %{python_files}
%doc README.rst
# no license available, neither in the tarball nor upstream
%{python_sitelib}/*

%changelog
* Thu Mar 26 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.9.2
  * Support ODM before_save hook on Python 3
* Fri Jul 26 2019 Marketa Calabkova <mcalabkova@suse.com>
- rewrite to single-spec
- update to 0.9.1
  * Deprecation of make_safe for Ming Documents
  * FormEncode is now an optional dependency only required for
    projects relying on ming.configure.
  * Python 3.7 is now officially supported
  * Support distinct() on cursors (already supported on collections)
- patch 0001-disable_test_gridfs.patch still relevant probably due
  to too new pymongo, gridfs tests are still failing
- Added patch pymongo-reqs.patch to unpin pymongo version
* Sun Apr 12 2015 benoit.monin@gmx.fr
- update to 0.5.1:
  * Cursor compatibility for Python 3
- additional changes from 0.5.0:
  * Compatible with pymongo 2.7
  * Compatible with Python 3.3 and 3.4
  * Compatible with PyPy
  * Fix update_if_not_modified
  * MIM: support float comparisons
  * ming.configure now allows any extra params to pass through to
    MongoClient
- additional changes from 0.4.7:
  * Add allow_none option to ForeignIdProperty
- additional changes from 0.4.6:
  * Fixed issue with if_missing for ForeignIdProperty
- additional changes from 0.4.5:
  * avoid extremely long error text
  * Fixed random generated ObjectId on empty ForeignIdProperty
- additional changes from 0.4.4:
  * Revert ForeignIdProperty None optimization
  * Fix delete event hook signatures
  * Fix typo when flushing an individual object flagged for deletion
- additional changes from 0.4.3:
  * Return result of update_partial()
  * ManyToMany support relying on a list of ObjectIds
  * Make RelationProperty writable
  * Support for all pymongo options in custom_indexes declaration
  * Permit relationships that point to same model
  * Fix wrong behavior for MIM find_and_modify new option and add
    test case
  * ForeignIdProperty None optimization
- additional changes from 0.4.2:
  * bool(cursor) now raises an Exception
  * schema migration now raises the new schema error if both old
    & new are invalid
  * aggregation methods added to session
  * MIM: support for indexing multi-valued properties
  * MIM: forcing numerical keys as strings
  * MIM: add `manipulate` arg to `insert` for closer pymongo
    compatibility
- refresh 0001-disable_test_gridfs.patch:
  * one test added back since it passes
  * three new tests skipped
- change source URL to pipy: sourceforge is not up to date
- add new dependency to python-six
- quiet the test run to avoid spamming to build log
* Fri Aug 15 2014 sfalken@opensuse.org
- Added 0001-disable_test_gridfs.patch
  + Disables build tests that were causing build to fail (sf#merciless/bugs/#27)
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Sep  2 2013 dmueller@suse.com
- update to 0.4.1:
  * removed ‘flyway’ package from ming. It is now available from
  https://github.com/amol-/ming-flyway This removes the dependency
  on PasteScript and will make Python 3 migration easier.
  * WebOb dependency is optional.
  * removed cursor.__len__ You must change len(query) to
  query.count() now. This prevents inadvertent extra count queries
  from running.
  * MIM: Support slicing cursors
  * MIM: Fixed exact dot-notation queries
  * MIM: Fixed dot-notation queries against null fields
  * MIM: Translate time-zone aware timestamps to UTC timestamps.
  pytz added as dependency
  * MIM: Allow the remove argument to find_and_modify
* Thu May 30 2013 dmueller@suse.com
- update to 0.3.6:
  * Renamed ming.orm to ming.odm
  * Lots of bug fixes
  * Add gridfs support to Ming
  * Add contextual ODM sessio
* Mon Apr 29 2013 dmueller@suse.com
- update to 0.3.3dev-20130322
  * various bugfixes, makes python-ceilometer testsuite almost pass
* Wed Jan 16 2013 saschpe@suse.de
- Disable testsuite on SLE, the unittest module is missing features
  on python-2.6
* Wed Jan 16 2013 saschpe@suse.de
- Add (optional) dependency on python-python-spidermonkey
* Wed Jan 16 2013 saschpe@suse.de
- Initial version
